==> fr-aster-9.3.0.1.tbz: aster/STA9.3/bibpyt/Messages/supervis.py <==
#@ MODIF supervis Messages  DATE 19/05/2008   AUTEUR LEFEBVRE J-P.LEFEBVRE 
# -*- coding: iso-8859-1 -*-
#            CONFIGURATION MANAGEMENT OF EDF VERSION
# ======================================================================
# COPYRIGHT (C) 1991 - 2006  EDF R&D                  WWW.CODE-ASTER.ORG
# THIS PROGRAM IS FREE SOFTWARE; YOU CAN REDISTRIBUTE IT AND/OR MODIFY
# IT UNDER THE TERMS OF THE GNU GENERAL PUBLIC LICENSE AS PUBLISHED BY
# THE FREE SOFTWARE FOUNDATION; EITHER VERSION 2 OF THE LICENSE, OR
# (AT YOUR OPTION) ANY LATER VERSION.
#
# THIS PROGRAM IS DISTRIBUTED IN THE HOPE THAT IT WILL BE USEFUL, BUT
# WITHOUT ANY WARRANTY; WITHOUT EVEN THE IMPLIED WARRANTY OF
# MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE. SEE THE GNU
# GENERAL PUBLIC LICENSE FOR MORE DETAILS.
#
# YOU SHOULD HAVE RECEIVED A COPY OF THE GNU GENERAL PUBLIC LICENSE
# ALONG WITH THIS PROGRAM; IF NOT, WRITE TO EDF R&D CODE_ASTER,
#    1 AVENUE DU GENERAL DE GAULLE, 92141 CLAMART CEDEX, FRANCE.
# ======================================================================

def _(x) : return x

cata_msg={

1 : _("""
 L'utilisation du mot-cl PAR_LOT='NON' permet d'accder en lecture et en criture
 au contenu des concepts Aster. De ce fait, votre tude est exclue du primtre
 qualifi de Code_Aster puisque toutes ses tapes ne peuvent tre certifies.

 Conseils :
   - Il n'y a pas particulirement de risque de rsultat faux... sauf si votre
     programmation l'introduit.
   - Distinguez le calcul lui-mme (qui doit sans doute passer en PAR_LOT='OUI')
     des post-traitements (qui ncessiteraient le mode PAR_LOT='NON') qui peuvent
     tre raliss en POURSUITE.
"""),

2: _("""
 Arret sur erreur(s) utilisateur
"""),

3: _("""
 Erreur programmeur : JEMARQ/JEDEMA non apparis.
"""),

4: _("""
 Commande n  %(k1)s  :  "%(k2)s"  :   %(k3)s  erreur(s) dtecte(s)
"""),

5: _("""
 Erreur(s)  l'excution de "%(k1)s" : arret immdiat du programme.
"""),

6: _("""
 Fin  la suite de message(s) <E>
"""),

7: _("""
 Le concept " %(k1)s " est inconnu.
 Il n'est ni parmi les crs, ni parmi ceux  crer.
"""),

8: _("""
 Un nom de concept intermdiaire doit commencer par '.' ou '_' et non :  %(k1)s
"""),

9: _("""
 Longueur nulle
"""),

10: _("""
   - le concept  "%(k1)s" est dtruit des bases de donnes.
"""),

11: _("""
 Impossible d'allouer la mmoire JEVEUX demande : %(i1)d Moctets.

 En gnral, cette erreur se produit car la mmoire utilise hors du fortran
 (jeveux) est importante.

 Causes possibles :
   - le calcul produit de gros objets Python dans une macro-commande ou
     dans le jeu de commande lui-mme,
   - le calcul appelle un solveur (MUMPS par exemple) ou un outil externe
     qui a besoin de mmoire hors jeveux,
   - utilisation de jeveux dynamique,
   - ...

 Solution :
   - distinguer la mmoire limite du calcul (case "Mmoire totale" de astk)
     de la mmoire rserve  jeveux (case "dont Aster"), le reste tant
     disponible pour les allocations dynamiques.
"""),

12: _("""
 Excution de JEVEUX en mode DEBUG
"""),

13: _("""
  %(k1)s  nom de base dj dfinie
"""),

14: _("""
  %(k1)s  statut impossible pour la base globale
"""),

15: _("""
 Problme d'allocation des bases de donnes
"""),

16: _("""
  Ecriture des catalogues dans ELEMBASE faite.
"""),

17: _("""
 Relecture des catalogues dans ELEMBASE faite.
"""),

18: _("""
  Trop de catalogues (maximum = 10)
"""),

19: _("""
 Debut de lecture
"""),

20: _("""
  "%(k1)s" argument invalide du mot cl "FICHIER" du mot cl facteur "CATALOGUE"
"""),

21: _("""
  Erreur(s) fatale(s) lors de la lecture des catalogues
"""),

23: _("""
 Debug JXVERI demand
"""),

24: _("""
 Debug SDVERI demand
"""),

25: _("""
 Mmoire gestion : "COMPACTE"
 Ce mode de gestion peut augmenter sensiblement le temps systme de certaines commandes,
 les lectures/critures sur les bases Jeveux tant beaucoup plus frquentes
"""),

26: _("""
 Type allocation memoire 2
"""),

27: _("""
 Type allocation memoire 3
"""),

28: _("""
 Type allocation memoire 4
"""),

29: _("""
 Trop de noms dfinis dans la liste argument de "FICHIER"
"""),

30: _("""
  %(k1)s est dj (re-) dfini
"""),

31: _("""
 Valeur invalide pour le mot cl RESERVE_CPU
"""),

32: _("""
 La procdure "%(k1)s" ne peut etre appele en cours d'excution des commandes
"""),

33: _("""
 Erreur fatale  **** appel  commande "superviseur".
"""),

34: _("""
 Arret de la lecture des commandes.
"""),

35: _("""
 La procdure "RETOUR" ne peut etre utilise dans le fichier principal de commandes.
"""),

36: _("""
 Le concept de nom '%(k1)s' n'existe pas
"""),

38: _("""
 Il n'y a plus de temps pour continuer
"""),

39: _("""
 Arret de l'excution et fermeture des bases jeveux
"""),

40: _("""
 Vous utilisez une version dont les routines suivantes ont t surcharges :
   %(ktout)s
"""),

41 : _("""
Le message d'alarme '%(k1)s' a t mis %(i1)d fois, il ne sera plus affich.
"""),

43: _("""
 Debug SDVERI suspendu
"""),

44: _("""
 Debug JEVEUX demand
"""),

45: _("""
 Debug JEVEUX suspendu
"""),

47: _("""
 Debug JXVERI suspendu
"""),

48: _("""
 Debug IMPR_MACRO demand
"""),

49: _("""
 Debug IMPR_MACRO suspendu
"""),

50: _("""
 la commande a un numro non appelable dans cette version.
 le numero erron est  %(i1)d
"""),

52: _("""
 fin de lecture (dure  %(r1)f  s.) %(k1)s
"""),

53: _("""
 vous ne pouvez utiliser plus de  %(i1)d
 niveaux de profondeur pour des appels par la procdure %(k1)s
"""),

55: _("""
 Appels rcursifs de messages d'erreur ou d'alarme.
"""),

56: _("""
 Incohrence entre le catalogue et le corps de la macro.
"""),

57: _("""
   Impossible d'importer '%(k1)s' dans Messages.
   Le fichier %(k1)s.py n'existe pas dans le rpertoire 'Messages'
   ou bien la syntaxe du fichier est incorrecte.

   Merci de signaler cette anomalie.

   Traceback :
   %(k2)s
"""),

60: _("""
 la procdure a un numro non appelable dans cette version.
 le numero errone est  %(i1)d
"""),

61: _("""
  La commande a un numro non appelable dans cette version
  Le numro erron est : %(i1)d
"""),

62: _("""
  Les messages d'erreurs prcdent concerne la commande :
"""),

63: _("""
     ARRET PAR MANQUE DE TEMPS CPU
     Les commandes suivantes sont ignorees, on passe directement dans FIN
     La base globale est sauvegardee
     Temps consomme de la reserve CPU        :  %(r1).2f s\n
"""),

64: _("""
  Valeur initiale du temps CPU maximum =   %(i1)d secondes
  Valeur du temps CPU maximum pass aux commandes =   %(i2)d secondes
  Rserve CPU prvue = %(i3)d secondes
"""),

65: _("""
   %(k1)s   %(k2)s   %(k3)s   %(k4)s
"""),

66: _("""
   %(k1)s   %(k2)s   %(k3)s   %(k4)s   %(k5)s
"""),

67: _("""
 Passage numro %(i1)d
"""),

68: _("""
 information sur les concepts devant etre crs.
"""),

69: _("""
   %(k1)s   %(k2)s   %(k3)s   %(k4)s
"""),

70: _("""
   %(k1)s   %(k2)s   %(k3)s   %(k4)s   %(k5)s
"""),

71: _("""
 rappel sur les executions prcdentes
   - il a ete execut %(i1)d procdures et oprateurs.
"""),

72: _("""
   - l'execution prcdente s'est termine correctement.
"""),

73: _("""

   - l'execution prcdente s'est termine en erreur dans la procdure %(k1)s.
"""),

74: _("""

   - l'execution prcdente s'est termine en erreur dans l'oprateur %(k1)s.
"""),

75: _("""
     le concept %(k1)s de type %(k2)s  est peut-etre errone.
"""),

76: _("""
   - l'execution precedente s'est terminee prematurement dans l'operateur %(k1)s.
"""),

77: _("""
     le concept %(k1)s de type %(k2)s  a ete nanmoims valid par l'oprateur
"""),

78: _("""
     Message attache au concept  %(k1)s
"""),

79: _("""
     Pas de message attache au concept %(k1)s
"""),

80: _("""

"""),

81: _("""
 %(k1)s nom symbolique inconnu
  - nombre de valeurs attendues %(i1)d
  - valeurs attendues : %(k1)s, %(k2)s,...
"""),

82: _("""
 L'argument du mot cle "CAS"  est errone.
 Valeur lue %(k1)s
 nombre de valeurs attendues %(i1)d
 valeurs attendues : %(k1)s,%(k2)s, ...
"""),

83: _("""

 le nombre d'enregistrements (nmax_enre) et leurs longueurs (long_enre) conduisent a un
fichier
 dont la taille maximale en octets (%(i1)d) est superieure a limite autorisee :  %(i2)d

"""),

84: _("""
 Nom symbolique errone pour un fichier de sortie
 Valeur lue %(k1)s
 - nombre de valeurs attendues %(i2)d
 - valeurs attendues           %(k2)s, %(k3)s

"""),

85: _("""
 information sur les concepts existants.
"""),

86: _("""
 Erreur a la relecture du fichier pick.1 : aucun objet sauvegard ne sera rcupr.
"""),

87: _("""
Types incompatibles entre glob.1 et pick.1 pour le concept de nom %(k1)s.
"""),

88: _("""
Concept de nom %(k1)s et de type %(k2)s introuvable dans la base globale"
"""),

# on ne veut pas mettre d'alarme mais que le message se voit, donc on fait la mise en forme ici !
89 : _("""
   !-----------------------------------------------------------------------!
   !   Liste des alarmes mises lors de l'excution du calcul.             !
   !                                                                       !
   !   Les alarmes que vous avez choisies d'ignorer sont prcdes de (*). !
   !   Nombre d'occurrences pour chacune des alarmes :                     !
"""),
        
90 : _("""   !      %(k1)3s %(k2)-20s mise %(i1)4d fois                         !
"""),

91 : _("""   !-----------------------------------------------------------------------!

"""),

92 : _("""   !          aucune alarme                                                !
"""),

}

==> fr-aster-9.4.0.2.tbz: aster/STA9.4/bibpyt/Messages/supervis.py <==
#@ MODIF supervis Messages  DATE 27/10/2008   AUTEUR COURTOIS M.COURTOIS 
# -*- coding: iso-8859-1 -*-
#            CONFIGURATION MANAGEMENT OF EDF VERSION
# ======================================================================
# COPYRIGHT (C) 1991 - 2006  EDF R&D                  WWW.CODE-ASTER.ORG
# THIS PROGRAM IS FREE SOFTWARE; YOU CAN REDISTRIBUTE IT AND/OR MODIFY
# IT UNDER THE TERMS OF THE GNU GENERAL PUBLIC LICENSE AS PUBLISHED BY
# THE FREE SOFTWARE FOUNDATION; EITHER VERSION 2 OF THE LICENSE, OR
# (AT YOUR OPTION) ANY LATER VERSION.
#
# THIS PROGRAM IS DISTRIBUTED IN THE HOPE THAT IT WILL BE USEFUL, BUT
# WITHOUT ANY WARRANTY; WITHOUT EVEN THE IMPLIED WARRANTY OF
# MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE. SEE THE GNU
# GENERAL PUBLIC LICENSE FOR MORE DETAILS.
#
# YOU SHOULD HAVE RECEIVED A COPY OF THE GNU GENERAL PUBLIC LICENSE
# ALONG WITH THIS PROGRAM; IF NOT, WRITE TO EDF R&D CODE_ASTER,
#    1 AVENUE DU GENERAL DE GAULLE, 92141 CLAMART CEDEX, FRANCE.
# ======================================================================

def _(x) : return x

cata_msg={

1 : _("""
 L'utilisation du mot-cl PAR_LOT='NON' permet d'accder en lecture et en criture
 au contenu des concepts Aster. De ce fait, votre tude est exclue du primtre
 qualifi de Code_Aster puisque toutes ses tapes ne peuvent tre certifies.

 Conseils :
   - Il n'y a pas particulirement de risque de rsultat faux... sauf si votre
     programmation l'introduit.
   - Distinguez le calcul lui-mme (qui doit sans doute passer en PAR_LOT='OUI')
     des post-traitements (qui ncessiteraient le mode PAR_LOT='NON') qui peuvent
     tre raliss en POURSUITE.
"""),

2: _("""
 Arret sur erreur(s) utilisateur
"""),

3: _("""
 Erreur programmeur : JEMARQ/JEDEMA non apparis.
"""),

4: _("""
 Commande n  %(k1)s  :  "%(k2)s"  :   %(k3)s  erreur(s) dtecte(s)
"""),

5: _("""
 Erreur(s)  l'excution de "%(k1)s" : arret immdiat du programme.
"""),

6: _("""
 Fin  la suite de message(s) <E>
"""),

7: _("""
 Le concept " %(k1)s " est inconnu.
 Il n'est ni parmi les crs, ni parmi ceux  crer.
"""),

8: _("""
 Un nom de concept intermdiaire doit commencer par '.' ou '_' et non :  %(k1)s
"""),

9: _("""
 Longueur nulle
"""),

10: _("""
   - le concept  "%(k1)s" est dtruit des bases de donnes.
"""),

11: _("""
 Impossible d'allouer la mmoire JEVEUX demande : %(i1)d Moctets.

 En gnral, cette erreur se produit car la mmoire utilise hors du fortran
 (jeveux) est importante.

 Causes possibles :
   - le calcul produit de gros objets Python dans une macro-commande ou
     dans le jeu de commande lui-mme,
   - le calcul appelle un solveur (MUMPS par exemple) ou un outil externe
     qui a besoin de mmoire hors jeveux,
   - utilisation de jeveux dynamique,
   - ...

 Solution :
   - distinguer la mmoire limite du calcul (case "Mmoire totale" de astk)
     de la mmoire rserve  jeveux (case "dont Aster"), le reste tant
     disponible pour les allocations dynamiques.
"""),

12: _("""
 Excution de JEVEUX en mode DEBUG
"""),

13: _("""
  %(k1)s  nom de base dj dfinie
"""),

14: _("""
  %(k1)s  statut impossible pour la base globale
"""),

15: _("""
 Problme d'allocation des bases de donnes
"""),

16: _("""
  Ecriture des catalogues dans ELEMBASE faite.
"""),

17: _("""
 Relecture des catalogues dans ELEMBASE faite.
"""),

18: _("""
  Trop de catalogues (maximum = 10)
"""),

19: _("""
 Debut de lecture
"""),

20: _("""
  "%(k1)s" argument invalide du mot cl "FICHIER" du mot cl facteur "CATALOGUE"
"""),

21: _("""
  Erreur(s) fatale(s) lors de la lecture des catalogues
"""),

# on ne veut pas mettre d'alarme mais que le message se voit, donc on fait la mise en forme ici !
22 : _("""
   !--------------------------------------------------------------------------------!
   !                                                                                !
   ! Le mot-cl facteur CODE dans DEBUT/POURSUITE est rserv aux cas-tests.        !
   ! Il ne faut pas l'utiliser dans les tudes car il modifie certaines valeurs par !
   ! dfaut des commandes DEBUT/POURSUITE, comme le comportement en cas d'erreur.   !
   !                                                                                !
   !--------------------------------------------------------------------------------!
"""),

23: _("""
 Debug JXVERI demand
"""),

24: _("""
 Debug SDVERI demand
"""),

25: _("""
 Mmoire gestion : "COMPACTE"
 Ce mode de gestion peut augmenter sensiblement le temps systme de certaines commandes,
 les lectures/critures sur les bases Jeveux tant beaucoup plus frquentes
"""),

26: _("""
 Type allocation memoire 2
"""),

27: _("""
 Type allocation memoire 3
"""),

28: _("""
 Type allocation memoire 4
"""),

29: _("""
 Trop de noms dfinis dans la liste argument de "FICHIER"
"""),

30: _("""
  %(k1)s est dj (re-) dfini
"""),

31: _("""
 Valeur invalide pour le mot cl RESERVE_CPU
"""),

32: _("""
 La procdure "%(k1)s" ne peut etre appele en cours d'excution des commandes
"""),

33: _("""
 Erreur fatale  **** appel  commande "superviseur".
"""),

34: _("""
 Arret de la lecture des commandes.
"""),

35: _("""
 La procdure "RETOUR" ne peut etre utilise dans le fichier principal de commandes.
"""),

36: _("""
 Le concept de nom '%(k1)s' n'existe pas
"""),

38: _("""
 Il n'y a plus de temps pour continuer
"""),

39: _("""
 Arret de l'excution et fermeture des bases jeveux
"""),

40: _("""
 Vous utilisez une version dont les routines suivantes ont t surcharges :
   %(ktout)s
"""),

41 : _("""
Le message d'alarme '%(k1)s' a t mis %(i1)d fois, il ne sera plus affich.
"""),

43: _("""
 Debug SDVERI suspendu
"""),

44: _("""
 Debug JEVEUX demand
"""),

45: _("""
 Debug JEVEUX suspendu
"""),

47: _("""
 Debug JXVERI suspendu
"""),

48: _("""
 Debug IMPR_MACRO demand
"""),

49: _("""
 Debug IMPR_MACRO suspendu
"""),

50: _("""
 la commande a un numro non appelable dans cette version.
 le numero erron est  %(i1)d
"""),

52: _("""
 fin de lecture (dure  %(r1)f  s.) %(k1)s
"""),

53: _("""
 vous ne pouvez utiliser plus de  %(i1)d
 niveaux de profondeur pour des appels par la procdure %(k1)s
"""),

55: _("""
 Appels rcursifs de messages d'erreur ou d'alarme.
"""),

56: _("""
 Incohrence entre le catalogue et le corps de la macro.
"""),

57: _("""
   Impossible d'importer '%(k1)s' dans Messages.
   Le fichier %(k1)s.py n'existe pas dans le rpertoire 'Messages'
   ou bien la syntaxe du fichier est incorrecte.

   Merci de signaler cette anomalie.

   Traceback :
   %(k2)s
"""),

60: _("""
 la procdure a un numro non appelable dans cette version.
 le numero errone est  %(i1)d
"""),

61: _("""
  La commande a un numro non appelable dans cette version
  Le numro erron est : %(i1)d
"""),

62: _("""
  Les messages d'erreurs prcdent concerne la commande :
"""),

63: _("""
     ARRET PAR MANQUE DE TEMPS CPU
     Les commandes suivantes sont ignorees, on passe directement dans FIN
     La base globale est sauvegardee
     Temps consomme de la reserve CPU        :  %(r1).2f s\n
"""),

64: _("""
  Valeur initiale du temps CPU maximum =   %(i1)d secondes
  Valeur du temps CPU maximum pass aux commandes =   %(i2)d secondes
  Rserve CPU prvue = %(i3)d secondes
"""),

65: _("""
   %(k1)s   %(k2)s   %(k3)s   %(k4)s
"""),

66: _("""
   %(k1)s   %(k2)s   %(k3)s   %(k4)s   %(k5)s
"""),

67: _("""
 Passage numro %(i1)d
"""),

68: _("""
 information sur les concepts devant etre crs.
"""),

69: _("""
   Destruction du concept '%(k1)s'.
"""),

70: _("""
   Validation du concept '%(k1)s'.
"""),

71: _("""
 rappel sur les executions prcdentes
   - il a ete execut %(i1)d procdures et oprateurs.
"""),

72: _("""
   - l'execution prcdente s'est termine correctement.
"""),

73: _("""

   - l'execution prcdente s'est termine en erreur dans la procdure %(k1)s.
"""),

74: _("""

   - l'execution prcdente s'est termine en erreur dans l'oprateur %(k1)s.
"""),

75: _("""
     le concept %(k1)s de type %(k2)s  est peut-etre errone.
"""),

76: _("""
   - l'execution precedente s'est terminee prematurement dans l'operateur %(k1)s.
"""),

77: _("""
     le concept %(k1)s de type %(k2)s  a ete nanmoims valid par l'oprateur
"""),

78: _("""
     Message attache au concept  %(k1)s
"""),

79: _("""
     Pas de message attache au concept %(k1)s
"""),

80: _("""

"""),

81: _("""
 %(k1)s nom symbolique inconnu
  - nombre de valeurs attendues %(i1)d
  - valeurs attendues : %(k1)s, %(k2)s,...
"""),

82: _("""
 L'argument du mot cle "CAS"  est errone.
 Valeur lue %(k1)s
 nombre de valeurs attendues %(i1)d
 valeurs attendues : %(k1)s,%(k2)s, ...
"""),

83: _("""

 le nombre d'enregistrements (nmax_enre) et leurs longueurs (long_enre) conduisent a un
 fichier dont la taille maximale en Moctets (%(i1)d) est superieure a limite autorisee :  %(i2)d
 
 Vous pouvez augmenter cette limite en utilisant l'argument "-max_base" sur la ligne
 de commande suivi d'une valeur en Moctets. 

"""),

84: _("""
 Nom symbolique errone pour un fichier de s.ortie
 Valeur lue %(k1)s
 - nombre de valeurs attendues %(i2)d
 - valeurs attendues           %(k2)s, %(k3)s

"""),

85: _("""
 information sur les concepts existants.
"""),

86: _("""
 Erreur a la relecture du fichier pick.1 : aucun objet sauvegard ne sera rcupr.
"""),

87: _("""
Types incompatibles entre glob.1 et pick.1 pour le concept de nom %(k1)s.
"""),

88: _("""
Concept de nom %(k1)s et de type %(k2)s introuvable dans la base globale"
"""),

# on ne veut pas mettre d'alarme mais que le message se voit, donc on fait la mise en forme ici !
89 : _("""
   !-----------------------------------------------------------------------!
   !   Liste des alarmes mises lors de l'excution du calcul.             !
   !                                                                       !
   !   Les alarmes que vous avez choisies d'ignorer sont prcdes de (*). !
   !   Nombre d'occurrences pour chacune des alarmes :                     !
"""),
        
90 : _("""   !      %(k1)3s %(k2)-20s mise %(i1)4d fois                         !
"""),

91 : _("""   !-----------------------------------------------------------------------!

"""),

92 : _("""   !          aucune alarme                                                !
"""),

}
